==> vue-grid-select-2.21.0.tgz: package/lib/index.js <==
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/grid-select/vue';
import Grid from '@opentinyvue/vue-grid';
import BaseSelect from '@opentinyvue/vue-base-select';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "GridSelect",
  components: {
    TinyGrid: Grid,
    TinyBaseSelect: BaseSelect
  },
  props: {
    clearable: Boolean,
    extraQueryParams: {
      type: [Object, String, Boolean, Array, Number],
      default: ""
    },
    filterable: Boolean,
    filterMethod: Function,
    gridOp: {
      type: Object,
      default: function _default() {
        return {};
      }
    },
    initLabel: {
      type: String,
      default: ""
    },
    initQuery: Function,
    modelValue: {},
    multiple: Boolean,
    radioConfig: {
      type: Object,
      default: function _default2() {
        return {
          checkMethod: function checkMethod() {
            return true;
          }
        };
      }
    },
    remote: Boolean,
    remoteConfig: {
      type: Object,
      default: function _default3() {
        return {
          showIcon: false,
          clearData: false,
          autoSearch: false
        };
      }
    },
    remoteMethod: Function,
    reserveKeyword: Boolean,
    selectConfig: {
      type: Object,
      default: function _default4() {
        return {
          checkMethod: function checkMethod() {
            return true;
          }
        };
      }
    },
    textField: {
      type: String,
      default: "label"
    },
    valueField: {
      type: String,
      default: "value"
    }
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("tiny-base-select", {
    ref: "baseSelectRef",
    staticClass: "tiny-grid-select",
    attrs: {
      "multiple": _vm.multiple,
      "filterable": _vm.filterable,
      "filter-method": _vm.filter
    },
    scopedSlots: _vm._u([{
      key: "panel",
      fn: function fn() {
        return [_c("tiny-grid", _vm._b({
          ref: "gridRef",
          attrs: {
            "auto-resize": "",
            "row-id": _vm.valueField,
            "select-config": _vm.buildSelectConfig(),
            "radio-config": _vm.buildRadioConfig(),
            "highlight-current-row": true,
            "columns": _vm.state.gridData.columns,
            "data": _vm.state.gridData
          },
          on: {
            "select-all": _vm.selectChange,
            "select-change": _vm.selectChange,
            "radio-change": _vm.radioChange,
            "mousedown": function mousedown($event) {
              $event.stopPropagation();
            }
          }
        }, "tiny-grid", _vm.gridOp, false))];
      },
      proxy: true
    }]),
    model: {
      value: _vm.state.value,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "value", $$v);
      },
      expression: "state.value"
    }
  });
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var GridSelect = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.21.0";
GridSelect.install = function(Vue) {
  Vue.component(GridSelect.name, GridSelect);
};
GridSelect.version = version;

export { GridSelect as default };

==> vue-grid-select-2.22.1.tgz: package/lib/index.js <==
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/grid-select/vue';
import Grid from '@opentinyvue/vue-grid';
import BaseSelect from '@opentinyvue/vue-base-select';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "GridSelect",
  components: {
    TinyGrid: Grid,
    TinyBaseSelect: BaseSelect
  },
  props: {
    clearable: Boolean,
    extraQueryParams: {
      type: [Object, String, Boolean, Array, Number],
      default: ""
    },
    filterable: Boolean,
    filterMethod: Function,
    gridOp: {
      type: Object,
      default: function _default() {
        return {};
      }
    },
    initLabel: {
      type: String,
      default: ""
    },
    initQuery: Function,
    modelValue: {},
    multiple: Boolean,
    radioConfig: {
      type: Object,
      default: function _default2() {
        return {
          checkMethod: function checkMethod() {
            return true;
          }
        };
      }
    },
    remote: Boolean,
    remoteConfig: {
      type: Object,
      default: function _default3() {
        return {
          showIcon: false,
          clearData: false,
          autoSearch: false
        };
      }
    },
    remoteMethod: Function,
    reserveKeyword: Boolean,
    selectConfig: {
      type: Object,
      default: function _default4() {
        return {
          checkMethod: function checkMethod() {
            return true;
          }
        };
      }
    },
    textField: {
      type: String,
      default: "label"
    },
    valueField: {
      type: String,
      default: "value"
    }
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("tiny-base-select", {
    ref: "baseSelectRef",
    staticClass: "tiny-grid-select",
    attrs: {
      "multiple": _vm.multiple,
      "filterable": _vm.filterable,
      "filter-method": _vm.filter
    },
    scopedSlots: _vm._u([{
      key: "panel",
      fn: function fn() {
        return [_c("tiny-grid", _vm._b({
          ref: "gridRef",
          attrs: {
            "auto-resize": "",
            "row-id": _vm.valueField,
            "select-config": _vm.buildSelectConfig(),
            "radio-config": _vm.buildRadioConfig(),
            "highlight-current-row": true,
            "columns": _vm.state.gridData.columns,
            "data": _vm.state.gridData
          },
          on: {
            "select-all": _vm.selectChange,
            "select-change": _vm.selectChange,
            "radio-change": _vm.radioChange,
            "mousedown": function mousedown($event) {
              $event.stopPropagation();
            }
          }
        }, "tiny-grid", _vm.gridOp, false))];
      },
      proxy: true
    }]),
    model: {
      value: _vm.state.value,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "value", $$v);
      },
      expression: "state.value"
    }
  });
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var GridSelect = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.undefined";
GridSelect.install = function(Vue) {
  Vue.component(GridSelect.name, GridSelect);
};
GridSelect.version = version;

export { GridSelect as default };
